==> openGion6.0.0.3_dev.zip: uap/webapps/gf/db/oracle/sql/install/08_CMNT/CMNT_TBL.sql <==
COMMENT ON TABLE GF01  IS 'ﾃｰﾌﾞﾙｽﾍﾟｰｽ定義'     ;
COMMENT ON TABLE GF02  IS 'ﾃｰﾌﾞﾙ定義'          ;
COMMENT ON TABLE GF05  IS 'ﾃｰﾌﾞﾙｶﾗﾑ定義'       ;
COMMENT ON TABLE GF06  IS 'ｲﾝﾃﾞｯｸｽ定義'        ;
COMMENT ON TABLE GF07  IS 'ｲﾝﾃﾞｯｸｽｶﾗﾑ定義'     ;
COMMENT ON TABLE GF09  IS 'ｼｰｹﾝｽ定義'          ;
COMMENT ON TABLE GF13  IS 'ｶﾚﾝﾀﾞｰﾌｧｲﾙ'         ;
COMMENT ON TABLE GF19  IS '予約語管理ﾃｰﾌﾞﾙ'    ;
COMMENT ON TABLE GF21  IS 'TAGLIBｸﾗｽ定義'      ;
COMMENT ON TABLE GF22  IS 'TAGLIB属性定義'     ;
COMMENT ON TABLE GF23  IS 'TAGLIB使用例ﾌｧｲﾙ'   ;
COMMENT ON TABLE GF24  IS 'JAVADOCｸﾗｽ定義ﾌｧｲﾙ' ;
COMMENT ON TABLE GF25  IS 'JAVADOC属性定義ﾌｧｲﾙ';
COMMENT ON TABLE GF27  IS '逆引ｷﾏﾆｭｱﾙ'         ;
COMMENT ON TABLE GF28  IS '対訳ﾃｰﾌﾞﾙ'          ;
COMMENT ON TABLE GF41  IS 'ﾄﾚｰﾆﾝｸﾞﾗﾍﾞﾙ定義'    ;
COMMENT ON TABLE GF42  IS '郵便番号定義'       ;
COMMENT ON TABLE GF43  IS '集計表ｻﾝﾌﾟﾙ'        ;
COMMENT ON TABLE GF44  IS 'ｻﾝﾌﾟﾙ社員定義'      ;
COMMENT ON TABLE GF45  IS '受注ﾃｰﾌﾞﾙｻﾝﾌﾟﾙ'     ;
COMMENT ON TABLE GF46  IS '位置情報ｻﾝﾌﾟﾙ'      ;
COMMENT ON TABLE GF60  IS 'ｵﾌﾞｼﾞｪｸﾄﾏｽﾀ定義'    ;
COMMENT ON TABLE GF61  IS 'ﾀｲﾌﾟ定義'           ;
COMMENT ON TABLE GF62  IS 'ﾌﾟﾛｼﾞｪｸﾄﾏｽﾀ定義'    ;
COMMENT ON TABLE GF63  IS 'ﾘｿｰｽﾏｽﾀ定義'        ;
COMMENT ON TABLE GF64  IS 'ﾀｽｸﾂﾘｰ'             ;
COMMENT ON TABLE GF65  IS 'ﾌﾟﾛｼﾞｪｸﾄﾘｿｰｽ定義'   ;
COMMENT ON TABLE GF66  IS 'ﾀｽｸﾘｿｰｽ定義'        ;
COMMENT ON TABLE GF67  IS 'ﾀｽｸｵﾌﾞｼﾞｪｸﾄ定義'    ;
COMMENT ON TABLE GF68  IS 'ﾘｿｰｽ計画ﾜｰｸ'        ;
COMMENT ON TABLE GF69  IS '不具合対策管理ﾃｰﾌﾞﾙ';
COMMENT ON TABLE GF70  IS 'JSPﾁｪｯｸ結果ﾃｰﾌﾞﾙ'   ;
COMMENT ON TABLE GF71  IS '画面関連状態ﾃｰﾌﾞﾙ'  ;
COMMENT ON TABLE GF72  IS '登録ﾎﾞﾀﾝ状態ﾃｰﾌﾞﾙ'  ;
COMMENT ON TABLE GF73  IS '使用ｶﾗﾑ状態ﾃｰﾌﾞﾙ'   ;
COMMENT ON TABLE GF74  IS 'QUERY状態ﾃｰﾌﾞﾙ'     ;
COMMENT ON TABLE GF75  IS 'JavaScript状態ﾃｰﾌﾞﾙ';
COMMENT ON TABLE GF76  IS 'ﾌｧｲﾙ検索ﾃｰﾌﾞﾙ'      ;
COMMENT ON TABLE GF77  IS 'ﾀｸﾞ検索ﾃｰﾌﾞﾙ'       ;
COMMENT ON TABLE GF78  IS '環境管理ﾃｰﾌﾞﾙ'      ;
COMMENT ON TABLE GF80  IS 'DB定義書ﾏｽﾀ'        ;
COMMENT ON TABLE GF81  IS 'ARG変数定義'        ;
COMMENT ON TABLE GF82  IS 'DBｵﾌﾞｼﾞｪｸﾄ一覧'     ;
COMMENT ON TABLE GF83  IS 'DBｵﾌﾞｼﾞｪｸﾄ明細'     ;
COMMENT ON TABLE GF84  IS '移行DB一覧'         ;
COMMENT ON TABLE GF85  IS '移行DB対応明細'     ;
COMMENT ON TABLE GF90  IS '青紙ﾃｰﾌﾞﾙ'          ;
COMMENT ON TABLE GF91  IS '青紙明細ﾃｰﾌﾞﾙ'      ;
COMMENT ON TABLE GF92  IS '画面項目定義ﾃｰﾌﾞﾙ'  ;
COMMENT ON TABLE GF93  IS '画面項目ﾘﾝｸ'        ;
COMMENT ON TABLE GF94  IS '項目ﾁｪｯｸ基準書'     ;
COMMENT ON TABLE GF95  IS 'DBｾｯﾄ基準書'        ;
COMMENT ON TABLE GF96  IS 'PG変更履歴'         ;
COMMENT ON TABLE GFW41 IS 'ﾄﾚｰﾆﾝｸﾞﾜｰｸ'         ;
COMMENT ON TABLE GFX01 IS 'GFX01'              ;
COMMENT ON TABLE GFX02 IS 'GFX02'              ;
COMMENT ON TABLE GFX03 IS 'GFX03'              ;

==> openGion6.2.5.1_dev.zip: uap/webapps/gf/db/oracle/sql/install/08_CMNT/CMNT_TBL.sql <==
COMMENT ON TABLE BONUS IS 'ﾎﾞｰﾅｽﾃｰﾌﾞﾙ'         ;
COMMENT ON TABLE DEPT  IS '部門ﾏｽﾀ'            ;
COMMENT ON TABLE EMP   IS '従業員ﾏｽﾀ'          ;
COMMENT ON TABLE GF01  IS 'ﾃｰﾌﾞﾙｽﾍﾟｰｽ定義'     ;
COMMENT ON TABLE GF02  IS 'ﾃｰﾌﾞﾙ定義'          ;
COMMENT ON TABLE GF03  IS 'ﾃｰﾌﾞﾙｶﾗﾑ定義ﾏｽﾀ'    ;
COMMENT ON TABLE GF05  IS 'ﾃｰﾌﾞﾙｶﾗﾑ定義'       ;
COMMENT ON TABLE GF06  IS 'ｲﾝﾃﾞｯｸｽ定義'        ;
COMMENT ON TABLE GF07  IS 'ｲﾝﾃﾞｯｸｽｶﾗﾑ定義'     ;
COMMENT ON TABLE GF09  IS 'ｼｰｹﾝｽ定義'          ;
COMMENT ON TABLE GF13  IS 'ｶﾚﾝﾀﾞｰﾌｧｲﾙ'         ;
COMMENT ON TABLE GF19  IS '予約語管理ﾃｰﾌﾞﾙ'    ;
COMMENT ON TABLE GF21  IS 'TAGLIBｸﾗｽ定義'      ;
COMMENT ON TABLE GF22  IS 'TAGLIB属性定義'     ;
COMMENT ON TABLE GF23  IS 'TAGLIB使用例ﾌｧｲﾙ'   ;
COMMENT ON TABLE GF24  IS 'JAVADOCｸﾗｽ定義ﾌｧｲﾙ' ;
COMMENT ON TABLE GF25  IS 'JAVADOC属性定義ﾌｧｲﾙ';
COMMENT ON TABLE GF27  IS '逆引ｷﾏﾆｭｱﾙ'         ;
COMMENT ON TABLE GF28  IS '対訳ﾃｰﾌﾞﾙ'          ;
COMMENT ON TABLE GF41  IS 'ﾄﾚｰﾆﾝｸﾞﾗﾍﾞﾙ定義'    ;
COMMENT ON TABLE GF42  IS '郵便番号定義'       ;
COMMENT ON TABLE GF43  IS '集計表ｻﾝﾌﾟﾙ'        ;
COMMENT ON TABLE GF44  IS 'ｻﾝﾌﾟﾙ社員定義'      ;
COMMENT ON TABLE GF45  IS '受注ﾃｰﾌﾞﾙｻﾝﾌﾟﾙ'     ;
COMMENT ON TABLE GF46  IS '位置情報ｻﾝﾌﾟﾙ'      ;
COMMENT ON TABLE GF60  IS 'ｵﾌﾞｼﾞｪｸﾄﾏｽﾀ定義'    ;
COMMENT ON TABLE GF61  IS 'ﾀｲﾌﾟ定義'           ;
COMMENT ON TABLE GF62  IS 'ﾌﾟﾛｼﾞｪｸﾄﾏｽﾀ定義'    ;
COMMENT ON TABLE GF63  IS 'ﾘｿｰｽﾏｽﾀ定義'        ;
COMMENT ON TABLE GF64  IS 'ﾀｽｸﾂﾘｰ'             ;
COMMENT ON TABLE GF65  IS 'ﾌﾟﾛｼﾞｪｸﾄﾘｿｰｽ定義'   ;
COMMENT ON TABLE GF66  IS 'ﾀｽｸﾘｿｰｽ定義'        ;
COMMENT ON TABLE GF67  IS 'ﾀｽｸｵﾌﾞｼﾞｪｸﾄ定義'    ;
COMMENT ON TABLE GF68  IS 'ﾘｿｰｽ計画ﾜｰｸ'        ;
COMMENT ON TABLE GF69  IS '不具合対策管理ﾃｰﾌﾞﾙ';
COMMENT ON TABLE GF70  IS 'JSPﾁｪｯｸ結果ﾃｰﾌﾞﾙ'   ;
COMMENT ON TABLE GF71  IS '画面関連状態ﾃｰﾌﾞﾙ'  ;
COMMENT ON TABLE GF72  IS '登録ﾎﾞﾀﾝ状態ﾃｰﾌﾞﾙ'  ;
COMMENT ON TABLE GF73  IS '使用ｶﾗﾑ状態ﾃｰﾌﾞﾙ'   ;
COMMENT ON TABLE GF74  IS 'QUERY状態ﾃｰﾌﾞﾙ'     ;
COMMENT ON TABLE GF75  IS 'JavaScript状態ﾃｰﾌﾞﾙ';
COMMENT ON TABLE GF76  IS 'ﾌｧｲﾙ検索ﾃｰﾌﾞﾙ'      ;
COMMENT ON TABLE GF77  IS 'ﾀｸﾞ検索ﾃｰﾌﾞﾙ'       ;
COMMENT ON TABLE GF78  IS '環境管理ﾃｰﾌﾞﾙ'      ;
COMMENT ON TABLE GF80  IS 'DB定義書ﾏｽﾀ'        ;
COMMENT ON TABLE GF81  IS 'ARG変数定義'        ;
COMMENT ON TABLE GF82  IS 'DBｵﾌﾞｼﾞｪｸﾄ一覧'     ;
COMMENT ON TABLE GF83  IS 'DBｵﾌﾞｼﾞｪｸﾄ明細'     ;
COMMENT ON TABLE GF84  IS '移行DB一覧'         ;
COMMENT ON TABLE GF85  IS '移行DB対応明細'     ;
COMMENT ON TABLE GF90  IS '青紙ﾃｰﾌﾞﾙ'          ;
COMMENT ON TABLE GF91  IS '青紙明細ﾃｰﾌﾞﾙ'      ;
COMMENT ON TABLE GF92  IS '画面項目定義ﾃｰﾌﾞﾙ'  ;
COMMENT ON TABLE GF93  IS '画面項目ﾘﾝｸ'        ;
COMMENT ON TABLE GF94  IS '項目ﾁｪｯｸ基準書'     ;
COMMENT ON TABLE GF95  IS 'DBｾｯﾄ基準書'        ;
COMMENT ON TABLE GF96  IS 'PG変更履歴'         ;
COMMENT ON TABLE GFW41 IS 'ﾄﾚｰﾆﾝｸﾞﾜｰｸ'         ;
COMMENT ON TABLE GFX01 IS 'GFX01'              ;
COMMENT ON TABLE GFX02 IS 'GFX02'              ;
COMMENT ON TABLE GFX03 IS 'GFX03'              ;
